@@ -9,6 +9,7 @@
 #include "Events/TextMsgEvent.h"
 #include "Shared/ERS210Info.h"
 #include "Shared/ERS220Info.h"
+#include <sstream>
 
 Controller * Controller::theOneController=NULL;
 
@@ -155,6 +156,26 @@ Controller& Controller::setEStopID(MotionManager::MC_ID estopid) {
 	return *this;
 }
 
+void Controller::loadGUI(const std::string& type, const std::string& name, unsigned int port, const std::vector<std::string>& args) {
+	std::stringstream ss;
+	ss << "load\n" << type << '\n' << name << '\n' << port << '\n';
+	for(unsigned int i=0; i<args.size(); i++) {
+		ss << '"';
+		for(unsigned int j=0; j<args[i].size(); j++) {
+			if(args[i][j]=='\\' || args[i][j]=='"' || args[i][j]=='\n')
+				ss << '\\';
+			ss << args[i][j];
+		}
+		ss << "\" ";
+	}
+	ss << '\n';
+	theOneController->gui_comm->write((const byte*)ss.str().c_str(),ss.str().size());
+}
+
+void Controller::closeGUI(const std::string& name) {
+	theOneController->gui_comm->printf("close\n%s\n",name.c_str());
+}
+
 int Controller::gui_comm_callback(char *buf, int bytes) {
 	std::string s(buf,bytes);
 	//	cout << "Controller Received: " << s << endl;
@@ -347,8 +368,8 @@ std::string Controller::removePrefix(const std::string& str, const std::string&
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_3 $
- * $Revision: 1.18 $
+ * $Name: tekkotsu-1_4 $
+ * $Revision: 1.20 $
  * $State: Exp $
- * $Date: 2003/06/12 18:06:07 $
+ * $Date: 2003/07/07 01:00:07 $
  */
