@@ -42,20 +42,32 @@
  *    <i>text:item-title<sub>numitems</sub></i>\n
  *    <i>text:item-description<sub>numitems</sub></i>' - refreshes the current menu\n
  *  - '<tt>status </tt><i>text</i>' - sets the status bar to <i>text</i> (until the next refresh)
+ *  - '<tt>load</tt>\n
+ *    <i>text:classname</i>\n
+ *    <i>text:instancename</i>
+ *    <i>int:port</i>\n
+ *    [<i>arg1</i> [<i>arg2</i> [...]]]' - tells the GUI to load the java class named <i>classname</i>, and have it connect to <i>port</i>, passing it the argument list.
+ *    <i>classname</i> should contain a constructor of the form <tt>Classname(String </tt><i>host</i>, <tt>int </tt><i>port</i>, <tt>String </tt><i>args</i><tt>[])</tt>
+ *    the argument list is parsed as if it were on the console - unescaped or unquoted spaces will separate args into elements in the array
+ *  - '<tt>close</tt>\n
+ *    <i>text:instancename</i>' - calls <tt>close()</tt> on an object previously created by a <tt>load</tt> message.
+ *    The Java object is expected to contain a function <tt>void close()</tt>.
+ *  
+ *  bool types are expected to be numerical values, 0 for false,
+ *  non-zero for true.
  *
- *  The upstream is the responsibility of the Controls, but the
- *  protocol is listed here to keep it together.  When a control's
+ *  <tt>load</tt> and <tt>close</tt> are intended to allow pop-up
+ *  windows for custom displays.
+ *
+ *  The upstream is the responsibility of the individual Controls, but
+ *  the protocol is listed here to keep it together.  When a control's
  *  state changes, it's that control's responsiblity to refresh the UI
  *  (LEDs, console, and GUI as appropriate).  Thus, future extensions
  *  to the upstream protocol are between the control which will use it
  *  and the GUI.  Future extensions to the downstream protocol would
  *  involve changing Controller and the GUI.
  *
- *  One additional upstream command for the 1.4 release is planned:
- *  - '<tt>load </tt><i>text:objectname</i> <i>int:port</i> [<i>arg1</i> [<i>arg2</i> [...]]]' - which will tell the GUI to load the java class named <i>objectname</i>, and have it connect to <i>port</i>, passing it the argument list.
- *
- *  This should allow pop-up windows with custom displays.  Also,
- *  the Controller may connect to serr in the future to pop-up an alert
+ *  The Controller may connect to serr in the future to pop-up an alert
  *  anytime output to serr occurs.
  *
  *  Note that all state is maintained on the robot - even if the GUI
@@ -103,6 +115,12 @@ class Controller : public BehaviorBase, public EventTrapper {
 	
 	virtual std::string getName() const { return "Controller"; }
 	static std::string getClassDescription() { return "Provides interface for activating/deactivating controls (and through them, behaviors)"; }
+	
+
+
+	static void loadGUI(const std::string& type, const std::string& name, unsigned int port) {loadGUI(type,name,port,std::vector<std::string>());} //!< attempts to open a Java object on the desktop
+	static void loadGUI(const std::string& type, const std::string& name, unsigned int port, const std::vector<std::string>& args); //!< attempts to open a Java object on the desktop
+	static void closeGUI(const std::string& name); //!< calls close() on a Java object loaded with loadGUI() (on the desktop)
 
 	static int gui_comm_callback(char *buf, int bytes); //!< called by wireless when there's new data from the GUI
 	static int console_callback(char *buf, int bytes);  //!< called by wireless when someone has entered new data on the tekkotsu console (NOT cin)
@@ -179,10 +197,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_3 $
- * $Revision: 1.14 $
+ * $Name: tekkotsu-1_4 $
+ * $Revision: 1.16 $
  * $State: Exp $
- * $Date: 2003/06/13 03:23:05 $
+ * $Date: 2003/07/08 18:01:21 $
  */
 
 #endif
