@@ -30,14 +30,16 @@ void HelpControl::report(ControlBase* r, const std::string& prefix) {
 		return;
 	const std::vector<ControlBase*>& slots=r->getSlots();
 	const std::string pre="  "+prefix;
-	int len=slots.size()==0?0:(int)(log(slots.size()-1)/log(10));
+	unsigned int numlen=1;
+	if(slots.size()>1)
+		numlen=(int)(log(slots.size()-1)/log(10))+1;
 	for(unsigned int i=0; i<slots.size(); i++) {
 		if(slots[i]==NULL)
 			continue;
 		char * fmt;
 		std::string nm=slots[i]->getName();
 		std::string desc=slots[i]->getDescription();
-		unsigned int len=term_width-(prefix.size()+nm.size()+2);
+		unsigned int len=term_width-(prefix.size()+nm.size()+4+numlen);
 		if((int)len<0)
 			len=0;
 		if(len>desc.size())
@@ -45,10 +47,10 @@ void HelpControl::report(ControlBase* r, const std::string& prefix) {
 		else
 			while(len>0 && !isspace(desc[len-1])) len--;
 		if(config->main.use_VT100)
-			fmt="\33[1m%s%*d%s\33[0m: %s\n";
+			fmt="\33[1m%s%*d. %s\33[0m: %s\n";
 		else
-			fmt="%s%*d.%s: %s\n";
-		sout->printf(fmt,prefix.c_str(),len,i,nm.c_str(),desc.substr(0,len).c_str());
+			fmt="%s%*d. %s: %s\n";
+		sout->printf(fmt,prefix.c_str(),numlen,i,nm.c_str(),desc.substr(0,len).c_str());
 		while(len<desc.size() && isspace(desc[len])) len++;
 		desc=desc.substr(len);
 		while(desc.size()>0) {
@@ -77,9 +79,9 @@ void HelpControl::report(ControlBase* r, const std::string& prefix) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_3 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-1_4 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2003/06/13 06:05:40 $
+ * $Date: 2003/07/09 00:10:57 $
  */
 
