@@ -18,7 +18,7 @@ class TailWagMC : public MotionCommand {
 	virtual int updateOutputs() {
 		if(active && state->robotDesign&WorldState::ERS210Mask) {
 			for(unsigned int i=0; i<NumFrames; i++)
-				pans[i].set(sin((2*M_PI*(get_time()+i*FrameTime))/period)*magnitude)
+				pans[i].set(sin((2*M_PI*(get_time()+i*FrameTime))/period)*magnitude); //bug fix thanks L.A.Olsson@herts.ac.uk
 			motman->setOutput(this,ERS210Info::TailOffset+PanOffset,pans);
 			motman->setOutput(this,ERS210Info::TailOffset+TiltOffset,tilt);
 			return 1;
@@ -51,10 +51,10 @@ class TailWagMC : public MotionCommand {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_3 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-1_4 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2003/06/12 23:41:40 $
+ * $Date: 2003/07/09 00:10:57 $
  */
 
 #endif
