@@ -99,8 +99,12 @@ void Config::readConfig(const char* filename) {
 					main.wsjoints_port=atoi(value);
 				} else if (strncasecmp(key,"wspids_port",29)==0) {
 					main.wspids_port=atoi(value);
-				} else if (strncasecmp(key,"mecha_port",29)==0) {
-					main.mecha_port=atoi(value);
+				} else if (strncasecmp(key,"headControl_port",29)==0) {
+					main.headControl_port=atoi(value);
+				} else if (strncasecmp(key,"walkControl_port",29)==0) {
+					main.walkControl_port=atoi(value);
+				} else if (strncasecmp(key,"estopControl_port",29)==0) {
+					main.estopControl_port=atoi(value);
 				} else if (strncasecmp(key,"aibo3d_port",29)==0) {
 					main.aibo3d_port=atoi(value);
 				} else if (strncasecmp(key,"use_VT100",29)==0) {
@@ -187,9 +191,9 @@ bool Config::extractBool(const char * value) {
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_3 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-1_4 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2003/06/12 23:41:40 $
+ * $Date: 2003/07/07 04:32:47 $
  */
 
