@@ -61,15 +61,17 @@ class Config {
 		int verbose_level; //!< controls verbosity of info
 		int wsjoints_port; //!< port to send joint positions on
 		int wspids_port;   //!< port to send pid info on
-		int mecha_port;	   //!< port for receiving mecha commands
+		int headControl_port;	   //!< port for receiving head commands
+		int walkControl_port;	   //!< port for receiving walk commands
+		int estopControl_port;	   //!< port for receiving walk commands
     int aibo3d_port;   //!< port for send/receive of joint positions from Aibo 3D GUI
 		bool use_VT100;    //!< if true, enables VT100 console codes (currently only in Controller menus - 1.3)
 
 		//!constructor
 		main_config()
 			: console_port(0), stderr_port(0), error_level(0), debug_level(0),
-				 verbose_level(0),wsjoints_port(0),wspids_port(0),mecha_port(0),
-				aibo3d_port(0), use_VT100(true)
+				verbose_level(0),wsjoints_port(0),wspids_port(0),headControl_port(0),
+				walkControl_port(0),estopControl_port(0),aibo3d_port(0), use_VT100(true)
 		{ }
 	} main;
 
@@ -152,10 +154,10 @@ extern Config* config;
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_3 $
- * $Revision: 1.14 $
+ * $Name: tekkotsu-1_4 $
+ * $Revision: 1.16 $
  * $State: Exp $
- * $Date: 2003/06/12 18:06:11 $
+ * $Date: 2003/07/07 04:32:47 $
  */
 
 #endif
