@@ -17,17 +17,17 @@ WorldStateSerializer::serialize() {
   char *buf=(char*)wsPIDs->getWriteBuffer((NumPIDJoints*3+1)*4);
   if (buf) {
     encode(&buf,state->lastSensorUpdateTime);
-    encode(&buf,(char*)state->pids,NumPIDJoints*3);
+    encode(&buf,(char*)state->pids,NumPIDJoints*3*4);
     wsPIDs->write((NumPIDJoints*3+1)*4);
   }
   
   buf=(char*)wsJoints->getWriteBuffer((NumPIDJoints*2+15)*4);
   if (buf) {
     encode(&buf,state->lastSensorUpdateTime);
-    encode(&buf,(char*)&state->outputs[PIDJointOffset], NumPIDJoints);
-    encode(&buf,(char*)state->sensors,6);
-    encode(&buf,(char*)state->buttons,8);
-    encode(&buf,(char*)state->pidduties,NumPIDJoints);
+    encode(&buf,(char*)&state->outputs[PIDJointOffset], NumPIDJoints*4);
+    encode(&buf,(char*)state->sensors,6*4);
+    encode(&buf,(char*)state->buttons,8*4);
+    encode(&buf,(char*)state->pidduties,NumPIDJoints*4);
     wsJoints->write((NumPIDJoints*2+15)*4);
   }
 }
