@@ -21,7 +21,6 @@
 #include "Behaviors/Controls/SavePostureControl.h"
 #include "Behaviors/Controls/SaveWalkControl.h"
 #include "Behaviors/Controls/ShutdownControl.h"
-#include "Behaviors/Controls/ToggleHeadLightControl.h"
 #include "Behaviors/Controls/ValueEditControl.h"
 #include "Behaviors/Controls/ValueSetControl.h"
 
@@ -40,8 +39,12 @@
 #include "Behaviors/Demos/WorldModel2Behavior.h"
 #include "Behaviors/Demos/DumbWM2Behavior.h"
 #include "Behaviors/Demos/SoundTestBehavior.h"
-#include "Behaviors/Demos/MechaControllerBehavior.h"
+#include "Behaviors/Demos/ToggleHeadLightBehavior.h"
+#include "Behaviors/Demos/WalkControllerBehavior.h"
+#include "Behaviors/Demos/HeadPointControllerBehavior.h"
 #include "Behaviors/Demos/Aibo3DControllerBehavior.h"
+#include "Behaviors/Demos/Aibo3DMonitorBehavior.h"
+#include "Behaviors/Demos/EStopControllerBehavior.h"
 
 #include "Motion/MotionCommand.h"
 #include "Motion/PostureMC.h"
@@ -164,18 +167,31 @@ StartupBehavior::SetupMenus() {
 			mcsetup.top()->pushSlot(new BehaviorSwitchControl<WorldModel2Behavior>("WorldModel2Behavior",bg,false));
 			mcsetup.pop();
 		}
-		mcsetup.top()->pushSlot(new ControlBase("Background Behaviors","Background daemons, servers, and monitors"));
+		mcsetup.top()->pushSlot(new ControlBase("Background Behaviors","Background daemons and monitors"));
 		{ 
 			mcsetup.push(mcsetup.top()->getSlots().back());
 			mcsetup.top()->pushSlot((new BehaviorSwitchControl<AutoGetupBehavior>("AutoGetupBehavior",false))->start());
 			mcsetup.top()->pushSlot((new BehaviorSwitchControl<BatteryMonitorBehavior>("BatteryMonitorBehavior",false))->start());
 			mcsetup.top()->pushSlot(new BehaviorSwitchControl<EvtRptBehavior>("EvtRptBehavior",false));
 			mcsetup.top()->pushSlot(new BehaviorSwitchControl<DumbWM2Behavior>("DumbWM2Behavior",false));
-			mcsetup.top()->pushSlot((new BehaviorSwitchControl<MechaControllerBehavior>("MechaController",false))->start());
-			mcsetup.top()->pushSlot((new BehaviorSwitchControl<Aibo3DControllerBehavior>("Aibo3DController",false))->start());
+			BehaviorSwitchControlBase::BehaviorGroup * aibo3D_bg = new BehaviorSwitchControlBase::BehaviorGroup();
+			mcsetup.top()->pushSlot((new BehaviorSwitchControl<Aibo3DControllerBehavior>("Aibo3DController",aibo3D_bg,false)));
+			mcsetup.top()->pushSlot((new BehaviorSwitchControl<Aibo3DMonitorBehavior>("Aibo3DMonitor",aibo3D_bg,false)));
 			mcsetup.top()->pushSlot(new BehaviorSwitchControl<HeadLevelBehavior>("HeadLevelBehavior",false));
 			if(state->robotDesign & WorldState::ERS220Mask)
-				mcsetup.top()->pushSlot(new ToggleHeadLightControl());
+				mcsetup.top()->pushSlot(new BehaviorSwitchControl<ToggleHeadLightBehavior>("ToggleHeadLightBehavior",false));
+			mcsetup.pop();
+		}
+		mcsetup.top()->pushSlot(new ControlBase("TekkotsuMon","Servers for GUIs"));
+		{ 
+			mcsetup.push(mcsetup.top()->getSlots().back());
+			mcsetup.top()->pushSlot((new BehaviorSwitchControl<HeadPointControllerBehavior>("Head Remote Control",false)));
+			mcsetup.top()->pushSlot((new BehaviorSwitchControl<WalkControllerBehavior>("Walk Remote Control",false)));
+			BehaviorSwitchControlBase::BehaviorGroup * aibo3D_bg = new BehaviorSwitchControlBase::BehaviorGroup();
+			mcsetup.top()->pushSlot((new BehaviorSwitchControl<Aibo3DControllerBehavior>("Aibo3D Controller",aibo3D_bg,false)));
+			mcsetup.top()->pushSlot((new BehaviorSwitchControl<Aibo3DMonitorBehavior>("Aibo3D Monitor",aibo3D_bg,false)));
+			EStopControllerBehavior * ESCB=new EStopControllerBehavior(stop_id);
+			mcsetup.top()->pushSlot((new BehaviorSwitchControl<EStopControllerBehavior,Factory1Arg<EStopControllerBehavior,MotionManager::MC_ID,MotionManager::invalid_MC_ID> >("EStop Remote Control",ESCB))->start());
 			mcsetup.pop();
 		}
 		mcsetup.top()->pushSlot(new ControlBase("Status Reports","Displays information about the runtime environment on the console"));
