@@ -17,15 +17,18 @@ public class ControllerGUI extends JFrame implements ActionListener {
 	JButton cancelBut;
 	JButton refreshBut;
 	JButton reconnectBut;
+	EStopPanel estop;
 	JTextField inputField;
 	boolean isUpdating=false;
 	
 	ControllerGUI(String addr, int port) {
+		super();
+		comm = new ControllerListener(addr,port);
+		comm.listener=this;
+		init();
 		pack();
 		setLocation(50,50);
 		show();
-		comm = new ControllerListener(addr,port);
-		comm.listener=this;
 	}
 	
 	// Disables the component if there's nothing selected to apply it to
@@ -130,6 +133,14 @@ public class ControllerGUI extends JFrame implements ActionListener {
 		}
 	}
  	
+	public class ReenableOnClose extends WindowAdapter {
+		JButton but;
+		public ReenableOnClose(JButton b) { but=b; }
+		public void windowClosing(WindowEvent e) {
+			e.getWindow().dispose();
+			but.setEnabled(true);
+		}
+	}
 
 	void updated() {
 			//		System.out.println("updated");
@@ -145,9 +156,9 @@ public class ControllerGUI extends JFrame implements ActionListener {
 			menu.setListData(new Vector());
 			status.setText("Reconnecting...");
 		} else {
-			title.setText((String)comm._titles.lastElement());
-			Vector menuitems=(Vector)comm._menus.lastElement();
-			synchronized(menu) {
+			synchronized(comm._menus) {
+				title.setText((String)comm._titles.lastElement());
+				Vector menuitems=(Vector)comm._menus.lastElement();
 				menu.setValueIsAdjusting(true);
 				menu.setListData(menuitems);
 				Vector sels=new Vector();
@@ -201,6 +212,14 @@ public class ControllerGUI extends JFrame implements ActionListener {
 			comm.kill();
 			comm = new ControllerListener(addr,port);
 			comm.listener=this;
+		} else if(evt.getActionCommand().compareTo("raw")==0 || evt.getActionCommand().compareTo("rle")==0) {
+			String[] tmp=new String[1];
+			tmp[0]=evt.getActionCommand();
+			VisionGUI vis=new VisionGUI(comm._host,tmp);
+			((JButton)evt.getSource()).setEnabled(false);
+			vis.addWindowListener(new ReenableOnClose((JButton)evt.getSource()));
+			vis.show();
+			vis.toFront();
 		}
 	}
 	
@@ -237,13 +256,11 @@ public class ControllerGUI extends JFrame implements ActionListener {
 		public Dimension getSize() { return dim; }
 	}
 
-	protected void frameInit() {
-		super.frameInit();
-		
+	protected void init() {
 		int spacer_size=10;
 	
 		
-		setTitle("Controller Menus");
+		setTitle("TekkotsuMon: Controller Menus");
 		getContentPane().setLayout(new BorderLayout());
 		getContentPane().add(Box.createHorizontalStrut(spacer_size),BorderLayout.WEST);
 		getContentPane().add(Box.createHorizontalStrut(spacer_size),BorderLayout.EAST);
@@ -294,15 +311,22 @@ public class ControllerGUI extends JFrame implements ActionListener {
 		}
 		statusbox.add(Box.createVerticalStrut(spacer_size-2));
 		{
-			Box tmp=Box.createHorizontalBox();
+			JPanel tmp=new JPanel(new BorderLayout());
 			status=new JLabel("Connecting...");
-			tmp.add(status);
-			tmp.add(Box.createHorizontalGlue());
-			reconnectBut=new JButton(carrows);
-			reconnectBut.setPreferredSize(new Dimension(carrows.getIconWidth(),carrows.getIconHeight()));
-			reconnectBut.addActionListener(this);
-			reconnectBut.setToolTipText("Drop current connection and try again.");
-			tmp.add(reconnectBut);
+			tmp.add(status,BorderLayout.CENTER);
+			{
+				Box tmp2=Box.createHorizontalBox();
+				estop=new EStopPanel(new EStopListener(comm._host,EStopListener.defPort));
+				estop.setPreferredSize(new Dimension(15,15));
+				tmp2.add(estop);
+				tmp2.add(Box.createHorizontalStrut(spacer_size));
+				reconnectBut=new JButton(carrows);
+				reconnectBut.setPreferredSize(new Dimension(carrows.getIconWidth(),carrows.getIconHeight()));
+				reconnectBut.addActionListener(this);
+				reconnectBut.setToolTipText("Drop current connection and try again.");
+				tmp2.add(reconnectBut);
+				tmp.add(tmp2,BorderLayout.EAST);
+			}
 			statusbox.add(tmp);
 		}
 		content.add(statusbox, BorderLayout.SOUTH);
@@ -327,12 +351,14 @@ public class ControllerGUI extends JFrame implements ActionListener {
 			Box tmp=Box.createHorizontalBox();
 			JButton but;
 			but=new JButton("Raw Cam");
-			but.setEnabled(false);
-			but.setToolTipText("Raw vision - Sorry not ready yet - check back next week!");
+			but.setToolTipText("Raw vision");
+			but.addActionListener(this);
+			but.setActionCommand("raw");
 			tmp.add(but);
 			but=new JButton("Seg. Cam");
-			but.setEnabled(false);
-			but.setToolTipText("Segmented vision - Sorry not ready yet - check back next week!");
+			but.setToolTipText("Segmented vision");
+			but.addActionListener(this);
+			but.setActionCommand("rle");
 			tmp.add(but);
 			tmp.setAlignmentX(0.0f);
 			p.add(tmp);
@@ -359,6 +385,7 @@ public class ControllerGUI extends JFrame implements ActionListener {
 		{
 			Box bbox=Box.createHorizontalBox();
 			bbox.setAlignmentX(0);
+			bbox.add(Box.createHorizontalGlue());
 			JButton tmp;
 			bbox.add(tmp=new JButton("Add"));
 			//			new AutoDisableListener(tmp,menu);
@@ -366,6 +393,7 @@ public class ControllerGUI extends JFrame implements ActionListener {
 			bbox.add(tmp=new JButton("Remove"));
 			new AutoDisableListener(tmp,bookmarks);
 			tmp.setEnabled(false);
+			bbox.add(Box.createHorizontalGlue());
 			p.add(bbox);
 		}
 
@@ -397,6 +425,10 @@ public class ControllerGUI extends JFrame implements ActionListener {
 			System.out.println("       if port is not specified, it defaults to 10020");
 			System.exit(2);
 		}
+
+		//    try { ClassPathModifier.addFile("../aibo3d"); }
+		//    catch (Exception ex) { System.out.println(ex); System.exit(1); }
+
 		int port=10020;
 		if(s.length>1)
 			port=Integer.parseInt(s[1]);
